# Security Policy

I take the security of my software and services seriously. This includes
all open source software I create, maintain or help to maintain.

If you believe you have found a security vulnerability in any repository
I maintain, including this one, please report it responsible to me as
described below.

**Please DO NOT report security vulnerabilities publicly!**

So... DO NOT create a GitHub issue for it ;)

## Reporting a vulnerability

Privately and confidently, send me a detailed description of the vulnerability
you have discovered using an encrypted and authenticated channel. Personally,
I prefer this to be done using PGP encrypted email. Contact information
needed for this is listed down below.

In the report, please include as much information as possible, including:

- A extensive description of the vulnerability.
- How it could be exploited.
- The potential impact you think it would have (e.g., DOS attackable, privacy
  concerns, leaking of credentials).
- Steps for reproducing the vulnerability.
- Code (if any), that is needed for reproducing the issue.
- If you have an idea for a fix, patch or any other adjustment for mitigating
  the vulnerability reported.

Sorry for the long list, but providing as much information as possible allows
me to act more quickly. Make sure to write your report in the English language.

Please take care not to violate the privacy of other people in your report.
For example, stack traces or exploit scripts sent to me should never contain
private or personally identifiable information.

## After you have reported the vulnerability

Give me at least a week to investigate and respond to the reported vulnerability
you have found; and up to 60 days to fix and distribute it. This includes a
window for existing users to upgrade, patch or mitigate the issue as well.

If you intent, at any point, to disclose the vulnerability to someone else
or maybe even publicly, please give me a reasonable advanced notice.

If any dependent projects are involved, I will take care of informing the
maintainers of those projects as well.

## Bug bounty

Unfortunately, I cannot offer a paid bug bounty program. I will, however, give
my best efforts to show appreciation towards people that took the time and
effort to disclose vulnerabilities responsibly.

Me, and the open source community, will be forever grateful.

Oh, and if we ever meet, I'm happy to buy you a beer :)

## Contact information

Please contact me, Troy Kelly, directly on:

troy@troykelly.com

GPG Fingerprint: `3DB9 B3FB 9D01 7C61 7365 222C A393 FFF4 401B D192`

https://keys.openpgp.org/search?q=3DB9B3FB9D017C617365222CA393FFF4401BD192

```txt
-----BEGIN PGP PUBLIC KEY BLOCK-----
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=
=9Okr
-----END PGP PUBLIC KEY BLOCK-----
```
